#!/usr/bin/perl
use strict;
use warnings;

use Test::More tests => 3;
use ExtUtils::Typemap;
use File::Spec;
use File::Temp;

my $datadir = -d 't' ? File::Spec->catdir(qw/t data/) : 'data';

sub slurp {
  my $file = shift;
  open my $fh, '<', $file
    or die "Cannot open file '$file' for reading: $!";
  local $/ = undef;
  return <$fh>;
}

my $first_typemap_file = File::Spec->catfile($datadir, 'simple.typemap');
my $second_typemap_file = File::Spec->catfile($datadir, 'other.typemap');
my $combined_typemap_file = File::Spec->catfile($datadir, 'combined.typemap');


my $first = ExtUtils::Typemap->new(file => $first_typemap_file);
isa_ok($first, 'ExtUtils::Typemap');
my $second = ExtUtils::Typemap->new(file => $second_typemap_file);
isa_ok($second, 'ExtUtils::Typemap');

$first->merge(typemap => $second);

is($first->as_string(), slurp($combined_typemap_file), "merging produces expected output");

